@@ -1,13 +1,13 @@
 #########################################################################################################
-# Collocation of Winds from Multiple Datasets
+# MAIN SCRIPT FOR Collocation of Winds from Multiple Datasets
 # 	-- This script has been specifically modified to collocate Aircraft winds (dataset 1) and AMVs (dataset 2) with Aeolus winds (driver dataset)
 #
-# CO-AUTHORS:   Katherine E. Lukens             NOAA/NESDIS/STAR, CISESS at U. of Maryland
+# CONTRIBUTORS: Katherine E. Lukens             NOAA/NESDIS/STAR, CISESS at U. of Maryland
 #               Kevin Garrett                   NOAA/NWS/OSTI
 #               Kayo Ide                        U. of Maryland
 #               David Santek                    CIMSS at U. of Wisconsin-Madison
 #               Brett Hoover                    NOAA/NWS/NCEP/EMC, Lynker Technologies
-#               David Huber                     NOAA/OAR/WPO/EPIC, Redline Performance Solutions, LLC
+#               David Huber                     NOAA/NWS/NCEP/EMC, Redline Performance Solutions, LLC
 #               Ross N. Hoffman                 NOAA/NESDIS/STAR, CISESS at U. of Maryland
 #               Hui Liu                         NOAA/NESDIS/STAR, CISESS at U. of Maryland
 #
@@ -48,6 +48,7 @@
 #########################################################################################################
 # Import python modules
 #########################################################################################################
+print("***** Import Python Modules *****")
 
 import os
 os.environ['OPENBLAS_NUM_THREADS'] = '1'
@@ -77,8 +78,8 @@ from read_data import read_loon
 from read_data import read_sonde
 
 ##############################################
-
-print("***** BEGIN MAIN PROGRAM *****")
+print("========================================")
+print("========== BEGIN MAIN PROGRAM ==========")
 
 runtype = "match"	# type of program coded here: MATCH code
 
@@ -158,10 +159,8 @@ for qc in qc_array:
   iqc = iqc + 1
   if iqc == 1:
     qc_drv_flag = int(qc)
-    print("DRIVER dataset QC? "+str(qc))
   elif iqc > 1:
     qc_dependent_flag.append(int(qc))
-    print("DEPENDENT dataset QC? "+str(qc))
 
 if iname!=iqc:
   print("ERROR: number of datasets does not equal number of QC dataset flags!")
@@ -251,7 +250,7 @@ hhARR		= [ "00","06","12","18" ]
 #=============================================
 # Find date before (B4) and date after (A) current date
 
-print("----- DATE = "+dateIN)
+print("----- DATE being processed = "+dateIN)
 
 yyyy = dateIN[0:4]
 mm   = dateIN[4:6]
@@ -316,9 +315,9 @@ yyyymmdd = yyyy+mm+dd		#Current date
 dateB4   = yyB4+mmB4+ddB4	#Day before current date
 dateA    = yyA+mmA+ddA		#Day after current date
  
-print("Current date to be processed = "+yyyymmdd)
-print("...Date before Current = "+dateB4) 
-print("...Date after Current = "+dateA)
+#print("Current date to be processed = "+yyyymmdd)
+print("...Date before = "+dateB4) 
+print("...Date after = "+dateA)
 
 yyyymmddhh = yyyymmdd+hour
 
@@ -598,15 +597,10 @@ if __name__ ==  '__main__':
 					 all_hgt_max ,
                                          usePH
                                         )
-    print("END obs_match_3d")
-    print("shape GCD_match: "+str(np.shape(GCD_match)))
-    print("shape DP_match: "+str(np.shape(DP_match)))
-    print("shape DPlog_match: "+str(np.shape(DPlog_match)))
-    print("shape HT_match: "+str(np.shape(HT_match)))
-    print("shape DT_match: "+str(np.shape(DT_match)))
-
-    print("shape of matched indices: DRIVER : "+str(np.shape(a_drv_idx)))
-    print("shape of matched indices: DEPENDENT : "+str(np.shape(a_match_idx)))
+    print("Number of matches = "+str(np.size(GCD_match))) # str(np.shape(GCD_match)))
+    if np.size(GCD_match)==0:
+      print("Zero matches found. EXIT PROGRAM")
+      sys.exit()		# if no matches between DRIVER and DEPENDENT, exit MAIN program
 
     # Get match indices from original files (before QC) - Driver dataset (AEOLUS)
     tmp = a_drv_idx
@@ -728,7 +722,7 @@ if __name__ ==  '__main__':
     
         # Split a_match_idx and a_drv_idx into two lists each, anything with an index value greater than dset1_len
     	# is in the second list, and corresponds to dset2 data, etc.
-    print("Get back original indices (those in the source data files) of dependent datasets")
+    print("Find matched indices from source data files")
 
     drv_size = np.nan * np.ones(ndependent_datasets,dtype=int)	# used to determine whether output NetCDF file should be created: if size(drv_flg)=0, do not create.
     
@@ -786,7 +780,7 @@ if __name__ ==  '__main__':
       	# Fill drv_size (for check later)
       
       drv_size[ndsets] = np.size(tmpdrv)
-      print("... ndsets = "+str(ndsets)+" | DRV_SIZE = "+str(drv_size[ndsets]))
+      #print("... ndsets = "+str(ndsets)+" | DRV_SIZE = "+str(drv_size[ndsets]))
 
       	#----------------------------	
       	# Collocation dimensions (GCD, DP, DT) for matched pairs
@@ -848,33 +842,23 @@ if __name__ ==  '__main__':
 
 	#------------------------------------------
 
-	# check size of 'drv_size' and set drv_flg=1 only if there are NO matches for ALL dependent datasets.
-    if np.sum(drv_size) == 0:
-      drv_flg = 1
-    else:
-      drv_flg = 0
-
-    if drv_flg == 1:
-      print("ERROR: There are zero matches between DRIVER ("+driver_name+") and all DEPENDENT datasets for DATE "+dateIN)
-      sys.exit()
-    elif drv_flg == 0:
     	# matches exist! create output file
-      print(str(dateIN)+" ... MATCHES EXIST! Continue creating output file")
+    print("Matches exist for "+str(dateIN)+"! Create output index file:")
 	    
     	# Send index values to netCDF file
-      nc_out_filenm = output_string+".nc4"
-      print("OUTPATH = "+output_path)
-      print("OUTFILE = "+nc_out_filenm)
+    nc_out_filenm = output_string+".nc4"
+    print("... OUTPATH = "+output_path)
+    print("... OUTFILE = "+nc_out_filenm)
     
       #==============================================================
       # Output variables and metadata to NetCDF
-      print("output to NetCDF")
-    
-      match_lists_to_netCDF(var_names,var_vals,nc_out_filenm,var_longnames,var_units,var_miss,var_path,var_qcflag,var_qclist,var_qcnotes,var_shortnames,var_aeol_wind_type,var_aeol_dset_type)
+
+    match_lists_to_netCDF(var_names,var_vals,nc_out_filenm,var_longnames,var_units,var_miss,var_path,var_qcflag,var_qclist,var_qcnotes,var_shortnames,var_aeol_wind_type,var_aeol_dset_type)
     
       #==============================================================
-    
-print("===== END MAIN PROGRAM =====")
+
+print("========== END MAIN PROGRAM ==========")
+print("======================================")    
 #########################################################################################################
 # END SCRIPT
 #########################################################################################################
