@@ -1,13 +1,13 @@
 ##########################################################################
 #
-# PYTHON 3 FUNCTIONS FOR quality_controls
+# PYTHON 3 FUNCTIONS FOR tools_analysis
 #
-# CO-AUTHORS:   Katherine E. Lukens             NOAA/NESDIS/STAR, CISESS at U. of Maryland
+# CONTRIBUTOS:  Katherine E. Lukens             NOAA/NESDIS/STAR, CISESS at U. of Maryland
 #               Kevin Garrett                   NOAA/NWS/OSTI
 #               Kayo Ide                        U. of Maryland
 #               David Santek                    CIMSS at U. of Wisconsin-Madison
 #               Brett Hoover                    NOAA/NWS/NCEP/EMC, Lynker Technologies
-#               David Huber                     NOAA/OAR/WPO/EPIC, Redline Performance Solutions, LLC
+#               David Huber                     NOAA/NWS/NCEP/EMC, Redline Performance Solutions, LLC
 #               Ross N. Hoffman                 NOAA/NESDIS/STAR, CISESS at U. of Maryland
 #               Hui Liu                         NOAA/NESDIS/STAR, CISESS at U. of Maryland
 #
@@ -342,7 +342,7 @@ def var_to_2d_counts_1dset(xstr,ystr,tx,ty,txvar0,tyvar0):
 	# fill grid cells where nsum=0 with nan
     nsum_nan0 = np.where(nsum0==0,np.nan,nsum0)
 
-    return nsum_nan0_arr	   	# return counts per grid cell
+    return nsum_nan0	   	# return counts per grid cell
 
 # -------------------------------------------------------------------------
 # Conform variable to 2 dimensions
@@ -505,5 +505,4 @@ def vert_interp(vcoord_data, interp_var, interp_levels):
     return interp_data
 
 
-
 #############################################################################
