@@ -1,13 +1,13 @@
 ###########################################################################
 #
-# PYTHON 3 FUNCTIONS FOR quality_controls
+# PYTHON 3 FUNCTIONS FOR tools_plotting
 #
-# CO-AUTHORS:   Katherine E. Lukens             NOAA/NESDIS/STAR, CISESS at U. of Maryland
+# CONTRIBUTORS: Katherine E. Lukens             NOAA/NESDIS/STAR, CISESS at U. of Maryland
 #               Kevin Garrett                   NOAA/NWS/OSTI
 #               Kayo Ide                        U. of Maryland
 #               David Santek                    CIMSS at U. of Wisconsin-Madison
 #               Brett Hoover                    NOAA/NWS/NCEP/EMC, Lynker Technologies
-#               David Huber                     NOAA/OAR/WPO/EPIC, Redline Performance Solutions, LLC
+#               David Huber                     NOAA/NWS/NCEP/EMC, Redline Performance Solutions, LLC
 #               Ross N. Hoffman                 NOAA/NESDIS/STAR, CISESS at U. of Maryland
 #               Hui Liu                         NOAA/NESDIS/STAR, CISESS at U. of Maryland
 #
@@ -70,6 +70,7 @@ import cartopy.mpl.ticker as cticker
 from cartopy.util import add_cyclic_point
 
 from tools_analysis import var_to_2d
+from tools_analysis import var_to_2d_counts_1dset
 
 #
 ###########################################################################
@@ -79,7 +80,7 @@ fill = -999
 
 	# font sizes for plots
 fonttitle  = 16
-fontaxis   = 14
+fontaxis   = 15
 fontlegend = 12
 
 ###########################################################################
@@ -88,7 +89,7 @@ fontlegend = 12
 #
 
 # -------------------------------------------------------------------------
-# (Zonal) Mean vs Height/Pressure of Matched Observations
+# Mean vs Height/Pressure of Matched Observations
 #
 def contour2d(var2d,var2dstr,xvar,yvar,xvarstr,yvarstr,tname,units,plottype,level,levunits,regionstr,**kwargs):
 
@@ -97,8 +98,8 @@ def contour2d(var2d,var2dstr,xvar,yvar,xvarstr,yvarstr,tname,units,plottype,leve
     
     ax1 = fig.add_subplot()
    
-    ax1.set_xlabel(xvarstr)
-    ax1.set_ylabel(yvarstr)
+    ax1.set_xlabel(xvarstr, fontsize=fontaxis)
+    ax1.set_ylabel(yvarstr, fontsize=fontaxis)
 
     if xvarstr.find('Time') != -1:
 	# get unique dates (yyyymmdd format)
@@ -142,21 +143,23 @@ def contour2d(var2d,var2dstr,xvar,yvar,xvarstr,yvarstr,tname,units,plottype,leve
       xvalues = np.arange(0,np.size(xvar),30)
       xlabels = xvar[::30]
       ax1.set_xticks(xvalues)
-      ax1.set_xticklabels(xlabels)
+      ax1.set_xticklabels(xlabels, fontsize=fontaxis-2)
       del xvalues,xlabels
 
     if yvarstr.find('Pressure') != -1:
-      yvalues = np.arange(0,np.size(yvar),10)
-      ylabels = yvar[::10]
+      nspacing = 4
+      yvalues = np.arange(0,np.size(yvar),nspacing)
+      ylabels = yvar[::nspacing]
       ax1.set_yticks(yvalues)
-      ax1.set_yticklabels(ylabels)
-      del yvalues,ylabels
+      ax1.set_yticklabels(ylabels, fontsize=fontaxis-2)
+      del yvalues,ylabels,nspacing
     elif yvarstr.find('Height') != -1:
-      yvalues = np.arange(0,np.size(yvar),10)
-      ylabels = yvar[::10]
+      nspacing = 2
+      yvalues = np.arange(0,np.size(yvar),nspacing)
+      ylabels = yvar[::nspacing]
       ax1.set_yticks(yvalues)
-      ax1.set_yticklabels(ylabels)
-      del yvalues,ylabels
+      ax1.set_yticklabels(ylabels, fontsize=fontaxis-2)
+      del yvalues,ylabels,nspacing
 
 	# set range of plotted colored contours
     warnings.filterwarnings('ignore', category=RuntimeWarning)		# ignore warnings
@@ -203,16 +206,19 @@ def contour2d(var2d,var2dstr,xvar,yvar,xvarstr,yvarstr,tname,units,plottype,leve
 
     if plottype=="2d":
       if var2dstr.find('Count') != -1:
-        pp = plt.imshow(var2d,cmap=ppcmap,norm=LogNorm(vmin=pltmin,vmax=pltmax), origin=originstr, aspect='auto')
+        if pltmax==10:
+          pp = plt.imshow(var2d,cmap=ppcmap,vmin=pltmin,vmax=pltmax, origin=originstr, aspect='auto')
+        else:
+          pp = plt.imshow(var2d,cmap=ppcmap,norm=LogNorm(vmin=pltmin,vmax=pltmax), origin=originstr, aspect='auto')
       else:
         pp = plt.imshow(var2d, cmap=ppcmap, vmin=pltmin, vmax=pltmax, origin=originstr, aspect='auto')
 
       if var2dstr.find('Count') != -1:
-        ax1.set_title(title+" Number Density of Matched Obs for "+tname)
+        ax1.set_title(title+" Number Density of Matched Obs for "+tname, fontsize=fonttitle-2)
       elif var2dstr.find('SD') != -1:
-        ax1.set_title(title+" "+var2dstr+" of Diff for "+tname)
+        ax1.set_title(title+" "+var2dstr+" of Diff for "+tname, fontsize=fonttitle-2)
       else:
-        ax1.set_title(title+" "+var2dstr+" "+str(level)+" "+levunits+" for "+tname)
+        ax1.set_title(title+" "+var2dstr+" "+str(level)+" "+levunits+" for "+tname, fontsize=fonttitle-2)
 
     elif plottype.find("map") != -1:
       x,y = np.meshgrid(xvar,yvar)
@@ -227,20 +233,23 @@ def contour2d(var2d,var2dstr,xvar,yvar,xvarstr,yvarstr,tname,units,plottype,leve
 
 	# plot
       if var2dstr.find('Count') != -1:
-        pp = plt.pcolormesh(x_cyc,yvararr,var2d_cyc,cmap=ppcmap,norm=LogNorm(vmin=pltmin,vmax=pltmax),transform=proj)
+        if pltmax==10:
+          pp = plt.pcolormesh(x_cyc,yvararr,var2d_cyc,cmap=ppcmap,vmin=pltmin,vmax=pltmax,transform=proj)
+        else:
+          pp = plt.pcolormesh(x_cyc,yvararr,var2d_cyc,cmap=ppcmap,norm=LogNorm(vmin=pltmin,vmax=pltmax),transform=proj)
       else:
         pp = plt.pcolormesh(x_cyc,yvararr,var2d_cyc, cmap=ppcmap, vmin=pltmin, vmax=pltmax, transform=proj)
 
       axmap.coastlines()
      
       if var2dstr.find('Count') != -1:
-        axmap.set_title(title+" Number Density of Matched Obs for "+tname)
+        axmap.set_title(title+" Number Density of Matched Obs for "+tname, fontsize=fonttitle-2)
       elif var2dstr.find('SD') != -1:
-        axmap.set_title(title+" "+var2dstr+" of Diff for "+tname)
+        axmap.set_title(title+" "+var2dstr+" of Diff for "+tname, fontsize=fonttitle-2)
       else: 
-        axmap.set_title(title+" "+var2dstr+" at "+str(level)+" "+levunits+" for "+tname)
+        axmap.set_title(title+" "+var2dstr+" at "+str(level)+" "+levunits+" for "+tname, fontsize=fonttitle-2)
 
-      gl = axmap.gridlines(draw_labels=True, linewidth=1, color='gray', alpha=0.5, linestyle='--')
+      gl = axmap.gridlines(draw_labels=True, linewidth=1, color='gray', alpha=0.7, linestyle='--')
       gl.xlines = True            # plot longitudes
       gl.ylines = True            # plot latitudes
       gl.top_labels=None
@@ -259,8 +268,8 @@ def contour2d(var2d,var2dstr,xvar,yvar,xvarstr,yvarstr,tname,units,plottype,leve
       		# define y-axis tickmarks
       gl.ylocator = mticker.FixedLocator([-90,-60,-30,0,30,60,90])
 
-      gl.xlabel_style = {'size': 15, 'color': 'gray'}
-      gl.ylabel_style = {'size': 15, 'color': 'gray'}
+      gl.xlabel_style = {'size': fontaxis, 'color': 'black'}#'gray'}
+      gl.ylabel_style = {'size': fontaxis, 'color': 'black'}#'gray'}
 
     if yvarstr.find('Pressure') != -1:
       plt.gca().invert_yaxis()
@@ -275,14 +284,19 @@ def contour2d(var2d,var2dstr,xvar,yvar,xvarstr,yvarstr,tname,units,plottype,leve
       cbarstr += " ("+str(units)+")"
 
     if xvarstr=='Time':
-      fig.colorbar(pp, label=cbarstr, orientation='horizontal', pad=0.125)
+      cbar = fig.colorbar(pp, label=cbarstr, orientation='horizontal', pad=0.125)
+    elif xvarstr=='Longitude' and yvarstr=='Latitude':
+      frac = 0.024
+      cbar = fig.colorbar(pp, label=cbarstr, orientation='vertical', fraction=frac, pad=0.04)
     else:   
-      fig.colorbar(pp, label=cbarstr, orientation='horizontal', pad=0.05)
+      frac = 0.046
+      cbar = fig.colorbar(pp, label=cbarstr, orientation='vertical', fraction=frac, pad=0.04)
+    cbar.ax.tick_params(labelsize=fontlegend)
 
     return fig
 
 # -------------------------------------------------------------------------
-# (Zonal) Mean vs Height/Pressure of Matched Observations
+# Mean vs Height/Pressure of Matched Observations
 #
 def contour2d_orthomap(datein,var2d,var2dstr,xvar,yvar,xvarstr,yvarstr,tname,units,center_lon,center_lat,level,levunits,**kwargs):
 
@@ -360,9 +374,27 @@ def contour2d_orthomap(datein,var2d,var2dstr,xvar,yvar,xvarstr,yvarstr,tname,uni
       # add coastlines
     axmap.coastlines(resolution='50m')
     axmap.set_global()
-    axmap.gridlines()
 
-              # plot on map
+      # set longitude gridlines and labels
+    nmerid = 30		# spacing for longitude lines
+    nzonal = 15		# spacing for latitude lines
+    num_merid = int(360/nmerid + 1)
+    num_zonal = int(90/nzonal + 1)
+    if center_lat>0: ylocsPole=np.linspace(0,90,num_zonal)	# NH
+    if center_lat==0: ylocsPole=np.linspace(-90,90,num_zonal)	# NH
+    if center_lat<0: ylocsPole=np.linspace(-90,0,num_zonal)	# SH
+    xlocsPole = np.linspace(-180,180,num_merid)
+    axmap.gridlines(xlocs=xlocsPole, ylocs=ylocsPole, linestyle="--", linewidth=1, color='gray', alpha=0.5)
+
+    gl = axmap.gridlines(draw_labels=False, linewidth=1, color='gray', alpha=0.5, linestyle='--')
+    gl.xlines = True            # plot longitudes
+    gl.ylines = True            # plot latitudes
+	# define x-axis tickmarks
+    gl.xlocator = mticker.FixedLocator(xlocsPole)#[-180,-120,-60,0,60,120,180])
+        # define y-axis tickmarks
+    gl.ylocator = mticker.FixedLocator(ylocsPole)#[-90,-60,-30,0,30,60,90])
+
+	# plot on map
     x,y = np.meshgrid(xvar,yvar)
     if var2dstr.find('Count') != -1:
       pp = axmap.scatter(x,y,c=var2d,cmap=ppcmap,norm=LogNorm(vmin=pltmin,vmax=pltmax),marker='s',s=5,transform=geo)
@@ -380,7 +412,8 @@ def contour2d_orthomap(datein,var2d,var2dstr,xvar,yvar,xvarstr,yvarstr,tname,uni
 	# is Count
       del cbarstr
       cbarstr = "Number Density of Matched Obs"
-    fig.colorbar(pp, label=cbarstr, orientation='horizontal', pad=0.025)
+    cbar = fig.colorbar(pp, label=cbarstr, orientation='vertical')#, pad=0.03)
+    cbar.ax.tick_params(labelsize=fontlegend)
 
     return fig
 
@@ -439,43 +472,35 @@ def contour2d_orthomap_rotate(datein,outpath,outname,var2d,var2dstr,xvar,yvar,xv
 # -------------------------------------------------------------------------
 # Density Scatter Plot
 #
-def density_scatter(nDuniq_list,Dlat,Dlon,tx,ty,x_name,y_name,units,regionstr,ax=None,sort=True,bins=20,**kwargs):
+def density_scatter(tx,ty,x_name,y_name,units,regionstr,ax=None,**kwargs):
+
+        # create plot
+    fig = plt.figure(figsize=(10,8.5))
 
-    	# create plot
-    fig = plt.figure(figsize=(11,8.5))		# (x,y) = (horiz,vert)
-    
     if ax is None:
       ax = plt.subplot()
-    
-  	# get colormap 'cmap'
-    cmap = plt.cm.get_cmap("jet")
 
     x = tx
     y = ty
 
-    	# compute density scattering  
-    bins = 15 	
+        # get colormap 'cmap'
+    ppcmap = plt.cm.get_cmap("jet")
 
-    data , x_e, y_e = np.histogram2d( x, y, bins = bins, density = False )
-
-    tz = interpn( ( 0.5*(x_e[1:] + x_e[:-1]) , 0.5*(y_e[1:]+y_e[:-1]) ) , data , np.vstack([x,y]).T , bounds_error = False)
-    z  = np.where(tz<=0,np.nan,tz)
-
-	# plot specs
+        # set plot specs
     if units=="m/s":
-      if x_name.find('Aeolus') != -1 or y_name.find('Aeolus') != -1: 
+      if x_name.find('Aeolus') != -1 or y_name.find('Aeolus') != -1:
         label = regionstr+" HLOS Wind Velocity"
         axismin = -100.0
         axismax = 100.0
-        txpos	= -95
-        typos	= 95
+        txpos   = -95
+        typos   = 95
         diffpos = 10
       else:
         label = regionstr+" Wind Speed"
         axismin = 0.0
         axismax = 100.0
-        txpos	= 5
-        typos	= 95
+        txpos   = 5
+        typos   = 95
         diffpos = 5
     elif units=="hPa":
       label = regionstr+" Pressure"
@@ -492,88 +517,114 @@ def density_scatter(nDuniq_list,Dlat,Dlon,tx,ty,x_name,y_name,units,regionstr,ax
       typos   = 19
       diffpos = 1
 
-        # statistical significance
-    signif = 95.0				       # statistical signifiance in percent (%). Type: float
+        # conform x,y to 2D array
+    gridcellsize = 1
+    xaxis = list(np.arange(axismin,axismax,gridcellsize))
+    yaxis = xaxis
+    var2d = var_to_2d_counts_1dset(x_name,y_name,xaxis,yaxis,x,y)
 
-    tsigmax = (100.0-signif)/100.0		       # max p-value allowed for statistical signiificance
+        # set range of plotted colored contours
+    warnings.filterwarnings('ignore', category=RuntimeWarning)          # ignore warnings
+    varmax = np.nanmax(var2d)
+    varmin = np.nanmin(var2d)
+        # reassign color range max
+    pltmin = 1
+    pltmax = 100
+    if varmax!=np.nan and varmax>=100000  : pltmax=1000000
+    if varmax!=np.nan and varmax<100000: pltmax=10000
+    if varmax!=np.nan and varmax<10000: pltmax=1000
+    if varmax!=np.nan and varmax<1000: pltmax=100
+    if varmax!=np.nan and varmax<100: pltmax=10
+    var2d  = np.where(var2d==np.nan,0,var2d)
+    del varmax,varmin
+
+	# plot
+    originstr = 'lower'
+    if pltmax==10:
+      pp = plt.imshow(var2d,cmap=ppcmap,vmin=pltmin,vmax=pltmax, extent=[axismin,axismax,axismin,axismax], origin=originstr, aspect='auto')
+    else:
+      pp = plt.imshow(var2d,cmap=ppcmap,norm=LogNorm(vmin=pltmin,vmax=pltmax), extent=[axismin,axismax,axismin,axismax], origin=originstr, aspect='auto')
+
+        # statistical significance
+    signif = 95.0                                      # statistical signifiance in percent (%). Type: float
+
+    tsigmax = (100.0-signif)/100.0                     # max p-value allowed for statistical signiificance
     tsig = ttest_ind(x,y).pvalue                       # get p-value from Student's t-test
     if tsig<=tsigmax:                                  # if p-value < tsigmax (difference is statistically significant at 95% level)
       statsigstr = "Diffs are signif. at "+str(int(signif))+"%"
-	
-	# create plot
-    pp = ax.scatter(x, y, c=z, s=5, cmap=cmap)
 
-	# set colorbar
-    fig.colorbar(pp, label="Number Density of Matched Obs")
-   
-	# set axis limits
+        # set axis limits
     ax.set_xlim([axismin,axismax])
     ax.set_ylim([axismin,axismax])
-    
-    ax.axhline(y=0,color="black")	      # horizontal line
-    ax.axvline(x=0,color="black")	      # vertical line
+    ax.tick_params(labelsize=fontaxis+2)
+
+
+    ax.axhline(y=0,color="black")             # horizontal line
+    ax.axvline(x=0,color="black")             # vertical line
     ax.axline((0,0),slope=1.0,color="black")  # one-to-one line
 
-      	# add text inside the plot
-    xpos = txpos				      # value on x-axis where text will begin
-    ypos = typos				      # value on y-axis where text will begin
-    ftsz = 8					      # font size of text_* (see below)
-    
+        # add text inside the plot
+    xpos = txpos                                      # value on x-axis where text will begin
+    ypos = typos                                      # value on y-axis where text will begin
+    ftsz = 12                                         # font size of text_* (see below)
+
         # add obs count to dataset name for legend
     legendlabel = str(y_name)+" count = "+str(np.size(y))
     ypos = ypos - diffpos
     plt.text(xpos, ypos, legendlabel, fontsize = ftsz)
-        
-	# compute and print stats of differences
+
+        # compute and print stats of differences
     diff = y - x
-    tcorr = np.corrcoef(x,y)	 # correlation
+    tcorr = np.corrcoef(x,y)     # correlation
     corr = tcorr[0,1]
-    avg  = np.mean(diff)		  # mean
-    sd   = np.std(diff) 		  # standard deviation
-    rmsd = np.sqrt(np.mean(diff**2))	  # RMSD
-		# add title for difference stats
+    avg  = np.mean(diff)                  # mean
+    sd   = np.std(diff)                   # standard deviation
+    rmsd = np.sqrt(np.mean(diff**2))      # RMSD
+                # add title for difference stats
     text = "Difference Stats ("+str(y_name)+" - DRIVER):"
     ypos = ypos - diffpos
     plt.text(xpos, ypos, text, fontsize = ftsz)
-		# add correlation
+                # add correlation
     textr = "r = "+str(np.round_(corr,decimals=2))
     ypos = ypos - diffpos/2
     plt.text(xpos, ypos, textr, fontsize = ftsz)
-		# add mean diff
+                # add mean diff
     textm = "Mean_Diff = "+str(np.round_(avg,decimals=2))
     ypos = ypos - diffpos/2
     plt.text(xpos, ypos, textm, fontsize = ftsz)
-		# add SD of diff
+                # add SD of diff
     texts = "SD_Diff = "+str(np.round_(sd,decimals=2))
     ypos = ypos - diffpos/2
     plt.text(xpos, ypos, texts, fontsize = ftsz)
-		# add RMSD
+                # add RMSD
     texts = "RMSD = "+str(np.round_(rmsd,decimals=2))
     ypos = ypos - diffpos/2
     plt.text(xpos, ypos, texts, fontsize = ftsz)
     if tsig<=tsigmax:
-		# add space
+                # add space
       texts = " "
       ypos = ypos - diffpos/2
       plt.text(xpos,ypos,texts,fontsize=ftsz)
-		# state whether differences are statistcially significant
+                # state whether differences are statistcially significant
       texts = statsigstr
       ypos = ypos - diffpos/2
       plt.text(xpos,ypos,texts,fontsize=ftsz)
       del tsig,tsigmax,signif
     del diff,tcorr,corr,avg,sd,rmsd,text,textr,textm,texts
- 
-      # plot title and axis labels    
-    ax.set_title(label+": "+str(y_name)+" vs DRIVER", fontsize=fonttitle)
-    ax.set_xlabel("DRIVER ("+x_name+") ("+str(units)+")", fontsize=fontaxis)
-    ax.set_ylabel(y_name+" ("+str(units)+")", fontsize=fontaxis)
-   
-    if units=="hPa":
-      plt.gca().invert_xaxis()
-      plt.gca().invert_yaxis()
 
-    return ax
-    
+      # plot title and axis labels
+    ax.set_title(label+": "+str(y_name)+" vs DRIVER", fontsize=fonttitle)
+    ax.set_xlabel("DRIVER ("+x_name+") ("+str(units)+")", fontsize=fontaxis+2)
+    ax.set_ylabel(y_name+" ("+str(units)+")", fontsize=fontaxis+2)
+
+        # Add a colorbar to the bottom of the plot.
+    cbarstr = "Number Density of Matched Obs"
+    frac = 0.046
+    cbar = fig.colorbar(pp, label=cbarstr, orientation='vertical', fraction=frac, pad=0.04)
+    cbar.ax.tick_params(labelsize=fontlegend+2)
+
+    return fig
+
 # -------------------------------------------------------------------------
 # Histogram of Collocation Differences
 #
@@ -977,8 +1028,6 @@ def map_contour2d_ce(var2dstr,var,flons,flats,tname,alphaval,datein,units,level,
     x,y = np.meshgrid(flons,flats)
     var_masked = np.ma.masked_where(var==np.nan, var)
 
-    print("map_contour2d_ce: shape x = "+str(np.shape(x))+" y = "+str(np.shape(y))+" var = "+str(np.shape(var))+" var_masked = "+str(np.shape(var_masked)))
-
     pp = plt.pcolormesh(x, y, var, cmap=ppcmap, transform=proj, zorder=3)
 
     ax.coastlines()
@@ -1116,8 +1165,7 @@ def map_locations_ortho(nDuniq_list,Ds,ss,Dx,tx,Dy,ty,x_name,y_name,marksize,ima
 def map_locations_ortho_rotate(outpath,outname,nDuniq_list,Ds,ss,Dx,tx,Dy,ty,x_name,y_name,marksize,imark,alphaval,dcolors,datein,center_lat,**kwargs):
 
 	# central points
-    #center_lons = [*range(0,360,1)]		# unpacks all values from 0 to (360-1)=359 with an increment of 1
-    center_lons = [*range(0,360,10)]
+    center_lons = [*range(0,360,10)]		# unpacks all values from 0 to (360-1)=359 with an increment of 1
     size_lons = np.size(center_lons)
 
 	# create directory to store all images for gif creation
@@ -1149,8 +1197,7 @@ def map_locations_ortho_rotate(outpath,outname,nDuniq_list,Ds,ss,Dx,tx,Dy,ty,x_n
     del size_lons
 
 	# make gif
-    #delay_sec = 10 				# time to display each image
-    delay_sec = 60
+    delay_sec = 60 #10 				# time to display each image
     infiles   = outpath_gif+"image_*.png"	# all images to use to create gif
     outfile   = outname+".gif"			# filename for output gif
 
@@ -1232,13 +1279,13 @@ def map_3d_profile(nDuniq_list,ss,xx,yy,zz,x_name,tname,dset_plotted,dset_plotte
     ax.add_collection3d(bm.drawcountries(linewidth=0.35),zs=zs_val)
 
 	# Add meridian and parallel gridlines
-    ax.set_xlabel('Longitude', labelpad=20)
-    ax.set_ylabel('Latitude', labelpad=20)
+    ax.set_xlabel('Longitude', fontsize=fontaxis-2,  labelpad=20)
+    ax.set_ylabel('Latitude', fontsize=fontaxis-2, labelpad=20)
     if zzlabel=="Pressure":
       zzunits = "(hPa)"
     elif zzlabel=="Height":
       zzunits = "(km)"
-    ax.set_zlabel(zzlabel+" "+zzunits, labelpad=20)
+    ax.set_zlabel(zzlabel+" "+zzunits, fontsize=fontaxis-2, labelpad=20)
 
     lon_step = 30
     lat_step = 30
@@ -1269,9 +1316,11 @@ def map_3d_profile(nDuniq_list,ss,xx,yy,zz,x_name,tname,dset_plotted,dset_plotte
     p = ax.scatter(xx, yy, zz, c=ss, cmap=ppcmap, vmin=pltmin, vmax=pltmax, s=5)#, alpha=0.5)
 
     	# add colorbar to reference intensity of 'ss'
-    fig.colorbar(p, label=sslabel)
+    cbar = fig.colorbar(p, label=sslabel)
+    cbar.ax.tick_params(labelsize=fontlegend)
     
-    plt.title(dset_plotted_name+" "+sslabel+" for "+str(datein), fontsize=9.5)
+    #plt.title(dset_plotted_name+" "+sslabel+" for "+str(datein), fontsize=9.5)
+    plt.title(dset_plotted_name+" "+sslabel, fontsize=fonttitle-2)
    
     return fig
     
@@ -1417,11 +1466,11 @@ def scatter_matches(nDuniq_list,Dlat,Dlon,Dvert,tx,ty,x_name,tname,marksize,alph
 def time_series(nDuniq_list,date_uniq,Dyyyymmdd,Dlat,Dlon,Dvert,tx,ty,x_name,tname,match_str,acolors,units,regionstr,latmin,latmax,**kwargs):
 	
 	# set font sizes for plotting
-    ftsz = 6 #8
+    ftsz = 9
     legendmarkersize = ftsz
     
 	# create plot
-    fig = plt.figure(figsize=(12,10))
+    fig = plt.figure(figsize=(12,12))
     
     	# create grid of panels
     gs = fig.add_gridspec(nrows=4, ncols=1)
@@ -1435,21 +1484,25 @@ def time_series(nDuniq_list,date_uniq,Dyyyymmdd,Dlat,Dlon,Dvert,tx,ty,x_name,tna
 	# panel specs
     if match_str=="HLOS":
       label = "HLOS Wind Velocity"
+      labelyaxis = "Wind"
       axismin = -5.0
       axismax = 5.0
       diffpos = 0.2
     elif match_str=="Wind Speed":
       label = match_str
+      labelyaxis = "Wind"
       axismin = -10.0
       axismax = 10.0
       diffpos = 5
     elif match_str=="Pressure":
       label = match_str
+      labelyaxis = label
       axismin = -15.0
       axismax = 15.0
       diffpos = -5
     elif match_str=="Height":
       label = match_str
+      labelyaxis = label
       axismin = -2.0
       axismax = 2.0
       diffpos = 0.5
@@ -1587,38 +1640,31 @@ def time_series(nDuniq_list,date_uniq,Dyyyymmdd,Dlat,Dlon,Dvert,tx,ty,x_name,tna
       sd_all   = np.mean(ssdtot)
       rmsd_all = np.mean(srmsdtot)
 
-      legendlabel = str(tname[i])+" | Mean_Diff="+str(np.round_(avg_all,decimals=2))+" SD_Diff="+str(np.round_(sd_all,decimals=2))+" RMSD="+str(np.round_(rmsd_all,decimals=2))
+      legendlabel1 = str(tname[i])+" | Mean_Diff="+str(np.round_(avg_all,decimals=2))
       del tcorr,xarr,yarr
     
     	# plot 1: time series: difference
-      ax1.plot(xaxis, diff, '-', color=acolors[i], linewidth=1, label=legendlabel)
-      leg1 = ax1.legend(loc='upper right', fontsize=ftsz)     
+      ax1.plot(xaxis, diff, '-', color=acolors[i], linewidth=1, label=legendlabel1)
  
         # plot 2: correlation coefficient
       legendlabel2 = str(tname[i])+" | r="+str(np.round_(corr_all,decimals=2))
       ax2.plot(xaxis, corr, color=acolors[i], label=legendlabel2)
-      leg2 = ax2.legend(loc='lower right', fontsize=ftsz)
 
         # plot 3: standard deviation, RMSD
+		# color lines legend
+      legendlabel3 = str(tname[i])+" | SD_Diff="+str(np.round_(sd_all,decimals=2))+" RMSD="+str(np.round_(rmsd_all,decimals=2))
+
+		# black lines legend
       custom_lines = [Line2D([0],[0],color="black",label="SD_Diff",linestyle="-"), Line2D([0],[0],color="black",label="RMSD",linestyle="--")]
 
-      ax3.plot(xaxis, sd, color=acolors[i])
+      ax3.plot(xaxis, sd, color=acolors[i], label=legendlabel3)
       ax3.plot(xaxis, rmsd, color=acolors[i], linestyle='dashed')
 
-      		# legend
-      leg3 = ax3.legend(handles=custom_lines, loc='lower right', fontsize=ftsz)
-      for lh3 in leg3.legendHandles:
-        lh3.set_alpha(1)
-      for lh3 in range(np.size(leg3.legendHandles)):
-        leg3.legendHandles[lh3]._sizes = [legendmarkersize]
-
       	# plot 4: number of observations
       legendlabel4 = str(tname[i])+" | count="+str(np.size(x))
       ax4.plot(xaxis, nobs, color=acolors[i], label=legendlabel4)		# add legend to bottom plot
-      leg4 = ax4.legend(loc='upper right', fontsize=ftsz)    
 
       del x,y,sd,rmsd,tmp_Dyyyymmdd
-      del custom_lines
 
 	# set tick marks for all panels
     ax1.set_xticks(xvalues)
@@ -1633,9 +1679,7 @@ def time_series(nDuniq_list,date_uniq,Dyyyymmdd,Dlat,Dlon,Dvert,tx,ty,x_name,tna
     ax4.set_xticklabels(xlabels, rotation=45)
     
     	# add DRIVER obs count to plot 1 legend
-    Dlegendlabel = "DRIVER ("+x_name+") Count = "+str(nDuniq_list)
-    t = ax1.text(2,axismin+1, Dlegendlabel, fontsize = ftsz)
-    t.set_bbox(dict(facecolor='white',alpha=0.75))		# set transparency of text box background
+    Dlegendlabel = "DRIVER Count = "+str(nDuniq_list)
 
 	# axis limits
     nobsarr = np.asarray(nobs)
@@ -1652,12 +1696,11 @@ def time_series(nDuniq_list,date_uniq,Dyyyymmdd,Dlat,Dlon,Dvert,tx,ty,x_name,tna
 	# plot 1 labels
     ax1.axhline(y=0,color="black")  	      			# horizontal line
     ax1.axvline(x=0,color="black")  	      			# vertical line
-    ax1.set_title("Time Series: "+regionstr+" "+label+" Difference (DEPENDENT - DRIVER)", fontsize=fonttitle)
-    ax1.set_ylabel(label+" Difference ("+units+")", fontsize=8)
+    ax1.set_title("Daily Mean Time Series: "+regionstr+" "+label+" Difference (DEPENDENT - DRIVER)", fontsize=fonttitle-2)
+    ax1.set_ylabel(labelyaxis+" Diff. ("+units+")", fontsize=10)
     
 		# legend
     leg1 = ax1.legend(loc='lower right', prop={'size': ftsz})
-
     for lh in leg1.legendHandles:
       lh.set_alpha(1)
     for lh in range(np.size(leg1.legendHandles)):
@@ -1666,7 +1709,7 @@ def time_series(nDuniq_list,date_uniq,Dyyyymmdd,Dlat,Dlon,Dvert,tx,ty,x_name,tna
         # plot 2 labels
     ax2.axhline(y=0,color="black")                              # horizontal line
     ax2.axvline(x=0,color="black")                              # vertical line
-    ax2.set_ylabel("Corr. Coeff. between Matches", fontsize=8)
+    ax2.set_ylabel("Corr. Coeff. (r)", fontsize=10)
 
                 # legend
     leg2 = ax2.legend(loc='lower right', prop={'size': ftsz})
@@ -1678,29 +1721,46 @@ def time_series(nDuniq_list,date_uniq,Dyyyymmdd,Dlat,Dlon,Dvert,tx,ty,x_name,tna
         # plot 3 labels
     ax3.axhline(y=0,color="black")                              # horizontal line
     ax3.axvline(x=0,color="black")                              # vertical line
-    ax3.set_ylabel("SD of Diff, RMSD ("+units+")", fontsize=8)
+    ax3.set_ylabel("RMSD, SD of Diff ("+units+")", fontsize=10)
 
-                # legend
-    custom_lines = [Line2D([0],[0],color="black",label="SD_Diff",linestyle="-"), Line2D([0],[0],color="black",label="RMSD",linestyle="--")]
-    leg3 = ax3.legend(handles=custom_lines, loc='lower right', prop={'size': ftsz})
-    for lh in leg3.legendHandles:
+		# color lines legend
+    leg3a = ax3.legend(loc='lower right', prop={'size': ftsz})
+    for lh in leg3a.legendHandles:
       lh.set_alpha(1)
-    for lh in range(np.size(leg3.legendHandles)):
-      leg3.legendHandles[lh]._sizes = [legendmarkersize]
+    for lh in range(np.size(leg3a.legendHandles)):
+      leg3a.legendHandles[lh]._sizes = [legendmarkersize]
 
+                # black lines legend
+    ax3b = ax3.twinx()
+    leg3b = ax3b.legend(handles=custom_lines, loc='lower left', prop={'size': ftsz})
+    for lh in leg3b.legendHandles:
+      lh.set_alpha(1)
+    for lh in range(np.size(leg3b.legendHandles)):
+      leg3b.legendHandles[lh]._sizes = [legendmarkersize] 
+    ax3b.tick_params(right=False,labelright=False)
+ 
 	# plot 4 labels
     ax4.axhline(y=0,color="black")  	      			# horizontal line
     ax4.axvline(x=0,color="black")  	      			# vertical line
-    ax4.set_ylabel("Count", fontsize=8)
+    ax4.set_ylabel("Count", fontsize=10)
     
 		# legend
     leg4 = ax4.legend(loc='upper right', prop={'size': ftsz})
-
     for lh in leg4.legendHandles:
       lh.set_alpha(1)
     for lh in range(np.size(leg4.legendHandles)):
       leg4.legendHandles[lh]._sizes = [legendmarkersize]
 
+		# DRIVER count legend
+    ax4D = ax4.twinx()
+    Dlegend = ax4D.plot([],[],' ',label=Dlegendlabel)
+    leg4D = ax4D.legend(handles=Dlegend, loc='upper left', prop={'size': ftsz})
+    for lh in leg4D.legendHandles:
+      lh.set_alpha(1)
+    for lh in range(np.size(leg4D.legendHandles)):
+      leg4D.legendHandles[lh]._sizes = [legendmarkersize]
+    ax4D.tick_params(right=False,labelright=False)
+
     del diff,nobs,diffarr,sdarr
 
     return fig
@@ -1843,11 +1903,12 @@ def z_distr(vertbinsP,vertbinsH,Dlat,Dlon,tx,ty,tz,x_name,tname,xvarstr,zvarstr,
 
     custom_lines = [Line2D([0],[0],color="black",label="Diff",linestyle="-"), Line2D([0],[0],color="black",label="SD_Diff",linestyle="--"), Line2D([0],[0],color="black",label="Stat Signif. "+str(int(signif))+"%",linestyle="None",marker="o")]
 
+	# set axes
     xvalues = list(np.arange(xmin,xmax,xstride))
     xlabels = xvalues
 
     axP1.set_xticks(xvalues)
-    axP1.set_xticklabels(xlabels)
+    axP1.set_xticklabels(xlabels, fontsize=fontaxis+2)
     axP1.set_ylim([min(vertbins),max(vertbins)])
 
     axP2.set_xlim([0,nobsmaxP])
@@ -1859,9 +1920,14 @@ def z_distr(vertbinsP,vertbinsH,Dlat,Dlon,tx,ty,tz,x_name,tname,xvarstr,zvarstr,
     ax2P2 = axP2.twinx()        # allows for 2nd y-axis to be plotted on same NOBS plot
     ax2P2.set_ylim([min(vertbins2),max(vertbins2)])
 
+    axP1.tick_params(axis='both', which='major', labelsize=fontaxis)
+    axP2.tick_params(axis='both', which='major', labelsize=fontaxis)
+    ax2P1.tick_params(axis='both', which='major', labelsize=fontaxis)
+    ax2P2.tick_params(axis='both', which='major', labelsize=fontaxis)
+
+	# plot lines
     for j in range(np.size(zvarstr)): 
       if np.size(diffP[j])>0:
-     	# plot lines
         if zvarstr[j]=="Pressure":
           if np.size(markers_on[j])>0:
             axP1.plot(diffP[j], vertbins, '-o', color=colorP[j], markevery=markers_on[j])
@@ -1889,9 +1955,9 @@ def z_distr(vertbinsP,vertbinsH,Dlat,Dlon,tx,ty,tz,x_name,tname,xvarstr,zvarstr,
     ax2P1.set_ylabel(ylabel2, fontsize=fontaxis)
     
 	# legend
-    legP1 = axP1.legend(handles=custom_lines, loc='lower left', prop={'size': fontlegend-2})
-    legP2 = axP2.legend(loc='upper right', prop={'size': fontlegend-2})
-    legP2 = ax2P2.legend(loc='upper center', prop={'size': fontlegend-2})
+    legP1 = axP1.legend(handles=custom_lines, loc='lower left', prop={'size': fontlegend})
+    legP2 = axP2.legend(loc='upper right', prop={'size': fontlegend-1})
+    legP2 = ax2P2.legend(loc='upper center', prop={'size': fontlegend-1})
 
     for lhP1 in legP1.legendHandles:
       lhP1.set_alpha(1)
@@ -2035,6 +2101,7 @@ def stats_windbins(bins,Dlat,tx,ty,x_name,tname,xvarstr,acolors,xunits,yunits,re
 
     custom_lines = [Line2D([0],[0],color="black",label="Diff",linestyle="-"), Line2D([0],[0],color="black",label="SD_Diff",linestyle="--"), Line2D([0],[0],color="black",label="SD_drv",linestyle="-."), Line2D([0],[0],color="black",label="SD_dep",linestyle=":"), Line2D([0],[0],color="black",label="Stat Signif. "+str(int(signif))+"%",linestyle="None",marker="o")]
 
+	# set axis limits
     if xvarstr=="Wind Speed":
       axP1.set_xlim([0,100])
       axP2.set_xlim([0,100])
@@ -2044,6 +2111,8 @@ def stats_windbins(bins,Dlat,tx,ty,x_name,tname,xvarstr,acolors,xunits,yunits,re
 
     axP1.set_ylim([ymin,ymax])
     axP2.set_ylim([0,nobsmax])
+    axP1.tick_params(axis='both', which='major', labelsize=fontaxis)              # change font size of major tick labels on both axes
+    axP2.tick_params(axis='both', which='major', labelsize=fontaxis)
 
     for j in range(np.size(acolors)): 
       if np.size(diff[j])>0:
@@ -2060,13 +2129,13 @@ def stats_windbins(bins,Dlat,tx,ty,x_name,tname,xvarstr,acolors,xunits,yunits,re
     	# left panel
     axP1.axhline(y=0,color="black")  	      			# horizontal line
     axP1.axvline(x=0,color="black")  	      			# vertical line
-    axP1.set_title(regionstr+" "+str(xvarstrplot)+" Stats: DEPENDENT - DRIVER", fontsize=fonttitle-2)
-    axP1.set_ylabel(ylabel, fontsize=10)
-    axP1.set_xlabel(xlabel, fontsize=10)
+    axP1.set_title(regionstr+" "+str(xvarstrplot)+" Stats: DEPENDENT - DRIVER", fontsize=fonttitle-3)
+    axP1.set_ylabel(ylabel, fontsize=fontaxis-3)
+    axP1.set_xlabel(xlabel, fontsize=fontaxis-3)
     
 	# legend
-    legP1 = axP1.legend(handles=custom_lines, loc='upper right', prop={'size': fontlegend-2})
-    legP2 = axP2.legend(loc='upper right', prop={'size': fontlegend-2})
+    legP1 = axP1.legend(handles=custom_lines, loc='upper right', prop={'size': fontlegend})
+    legP2 = axP2.legend(loc='upper right', prop={'size': fontlegend})
 
     for lhP1 in legP1.legendHandles:
       lhP1.set_alpha(1)
@@ -2082,12 +2151,12 @@ def stats_windbins(bins,Dlat,tx,ty,x_name,tname,xvarstr,acolors,xunits,yunits,re
 	# right panel
     #axP2.axhline(y=0,color="black")  	      			# horizontal line
     axP2.axvline(x=0,color="black")  	      			# vertical line
-    axP2.set_ylabel("Matched Obs Count", fontsize=10)
-    axP2.set_xlabel(xlabel, fontsize=10)
+    axP2.set_ylabel("Matched Obs Count", fontsize=fontaxis-3)
+    axP2.set_xlabel(xlabel, fontsize=fontaxis-3)
 
     fig.tight_layout()
 
     return fig
 
-    
+
 # -------------------------------------------------------------------------
